from django.contrib import admin
from .models import Page


class PageAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'created', 'last_updated')
    search_fields = ('id', 'name')
admin.site.register(Page, PageAdmin)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals
from django.db import models
from django.utils.encoding import python_2_unicode_compatible

from tinymce.models import HTMLField


@python_2_unicode_compatible
class Page(models.Model):
    name = models.CharField(max_length=200, db_index=True)
    content = HTMLField()
    created = models.DateTimeField(auto_now_add=True)
    last_updated = models.DateTimeField(auto_now=True)

    def __str__(self):
        return 'Page: ' + str(self.name)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_cow
------------

Tests for `cow` models module.
"""
from datetime import timedelta
from uuid import uuid4

from django.test import TestCase
from django.utils import timezone

from cow import models


class TestCow(TestCase):
    def setUp(self):
        self.pages = []
        for i in range(9):
            page = models.Page.objects.create(name='test1', content=str(i))
            self.pages.append(page)
            page.created -= timedelta(days=i)
            page.save()

    def test_generate_simple(self):
        # stupid test to touch code/models
        extra = models.Page.objects.create(name='test1', content='2')
        extra.delete()

    def tearDown(self):
        for page in self.pages:
            page.delete()
